/*  This is the mk4 instrument description header file.
    It contains information necessary to describe
    how the mk4 instrument was configured during any time period.

    Set up by Alice Lecinski in fall of 2001.

    I strongly suggest *not* editting this code at all, unless
    you are absolutely sure you've found an error that
    needs fixing.

    If you edit it, you risk destroying the integrity of the
    code.  So if you do edit it, insure results pre and post
    actually match.

*/

#define EPOCH        (2000)
#include <stdio.h>
#include <ctype.h>

    /*   Path to the "correct" files
	 "/thisbe/e/elmore/MkIV/Correct/"   --- a temporary location
	 "/puu/f/cordyn/mk4_cal/"           --- the permanent location
	 "/local/d/Data/Cal"                --- the location on nahenahe    
    */

    /*   r0 and dr are computed from a MASK image.   

         There was a case statement in David's code,
	     if ( meanpix(0) lt 60 ) then heights(0) = 1.185
           
         David didn't know why the case statement was in there, so 
         the height(0) = 1.224 was used instead. 
         This gives a better fit.

         Oh, just to document it, the heights for the MASK slots
         are  = [1.224,1.804,2.287]  all in Rsun,
         assuming a Rsun of 960 arc-seconds.

	 The hairlines are computed from the i data
	 closest to the MASK image.
    */
    /*
	 The JuldRange is a bit non-standard.
	 A standard Julian day begins at noon.
	 But here, I (Alice Lecinski) begin the
	 Julian day at midnight.
	 I also use an offset of 2415021 (Jan 1, 1900)

	 So, Standard_JulianDay = JuldRange + 2415021 - 0.5

	 To convert JuldRange numbers to
	 a date and time, use the program:
	     mk4IDjd2datetime
	 e.g.
	     mk4IDjd2datetime 36109.7868
    */

#define NUM_IDS  (42)

struct InstrDescrip InDe[NUM_IDS] = 
    {   

       /* 36094        -- 98d301 , Oct 28, 1998 Mk4 instrument installed. */

       /* 36106.7944   -- 98d313 , Nov 9, 1998 first corrector table. */

       {36094.0000 ,          /* Valid juld range */
	36109.7861 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.9033  , 0.005267  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199811091904",  "gain_1.199811091904" } ,


       /* 98d316 , Nov 12, 1998 */
       {36109.7868 ,          /* Valid juld range */
	36122.7847 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.9033  , 0.005267  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199811121853",  "gain_1.199811121853" } ,

       /* 98d329 , Nov 25, 1998 */
       {36122.7854 ,          /* Valid juld range */
	36124.7667 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.9033  , 0.005267  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199811251851",  "gain_1.199811251851" } ,

       /* 98d331 , Nov 27, 1998 */
       {36124.7674 ,          /* Valid juld range */
	36126.7924 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.9033  , 0.005267  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199811271825",  "gain_1.199811271825" } ,

       /* 98d333 , Nov 29, 1998 */
       {36126.7931 ,          /* Valid juld range */
	36163.0000 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.9033  , 0.005267  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199811291902",  "gain_1.199811291902" } ,

       /* 99d005 , Jan 5, 1999  -- 36163 
	  mask test day 
       */
       {36163.0001 ,          /* Valid juld range */
	36194.0000 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.9062  , 0.005233  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199811291902",  "gain_1.199811291902" } ,

       /* 99d036 , Feb 5, 1999  -- 36194 
	  mask test day 
       */
       {36194.0001 ,          /* Valid juld range */
	36271.8924 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.8976  , 0.005224  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199811291902",  "gain_1.199811291902" } ,







       /* 99d113 , April 23, 1999 */
       {36271.8931 ,          /* Valid juld range */
	36271.9035 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.8976  , 0.005224  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199904232126",  "gain_1.199904232126" } ,

       /* 99d113 , April 23, 1999 */
       {36271.9042 ,          /* Valid juld range */
	36278.0000 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	0.8976  , 0.005224  , /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199904232142",  "gain_1.199904232142" } ,






       /* 36728 -- 99d120 , April 30 1999 
	  mask test day 
       */
       {36278.0001 ,          /* Valid juld range */
	36279.8125 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199904232142",  "gain_1.199904232142" } ,


       /* 99d121 , May 1 1999 */
       {36279.8132 ,          /* Valid juld range */
	36351.8319 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199905011931",  "gain_1.199905011931" } ,

       /* 99d193 , July 12, 1999 */
       {36351.8326 ,          /* Valid juld range */
	36351.8660 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199907121959",  "gain_1.199907121959" } ,

       /* 99d193 , July 12, 1999 */
       {36351.8667 ,          /* Valid juld range */
	36351.8840 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199907122048",  "gain_1.199907122048" } ,

       /* 99d193 , July 12, 1999 */
       {36351.8847 ,          /* Valid juld range */
	36354.7757 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199907122114",  "gain_1.199907122114" } ,

       /* 99d196 , July 15, 1999 */
       {36354.7764 ,          /* Valid juld range */
	36354.8597 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199907151838",  "gain_1.199907151838" } ,

       /* 99d196 , July 15, 1999 */
       {36354.8604 ,          /* Valid juld range */
	36387.7403 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199907152039",  "gain_1.199907152039" } ,

       /* 99d229 , Aug 17, 1999 */
       {36387.7410 ,          /* Valid juld range */
	36388.7431 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199908171747",  "gain_1.199908171747" } ,

       /* 99d230 , Aug 18, 1999 */
       {36388.7438 ,          /* Valid juld range */
	36389.8333 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199908181751",  "gain_1.199908181751" } ,

       /* 99d231 , Aug 19, 1999 */
       {36389.8340 ,          /* Valid juld range */
	36396.7965 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199908192001",  "gain_1.199908192001" } ,

       /* 99d238 , Aug 26, 1999 */
       {36396.7972 ,          /* Valid juld range */
	36432.0000 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	0.0,  0.0,            /* hairspots from data near mask test */
	1.00156 , 0.00503576, /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199908261908",  "gain_1.199908261908" } ,




       /* Oct 1, 1999, doy 274  
	  Hairlines installed 
	  mask test
       */


       {36432.0001 ,          /* Valid juld range */
	36446.7521 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	106.000,  276.500,    /* hairspots from data near mask test */
	0.9139 ,  0.005269 ,  /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199908261908",  "gain_1.199908261908" } ,

       /* Oct 15, 1999, doy 288 */
       {36446.7528 ,          /* Valid juld range */
	36640.8285 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	106.000,  276.500,    /* hairspots from data near mask test */
	0.9139 ,  0.005269 ,  /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.199910151804",  "gain_1.199910151804" } ,

       /* April 26, 2000, doy 117 */
       {36640.8292 ,          /* Valid juld range */
	36898.8528 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	106.000,  276.500,    /* hairspots from data near mask test */
	0.913900, 0.005269,   /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200004261954",  "gain_1.200004261954" } ,

       /* Jan 9, 2001, doy 9 */
       {36898.8535 ,          /* Valid juld range */
	37007.0368 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	0.3,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	106.000,  276.500,    /* hairspots from data near mask test */
	0.913900, 0.005269,   /* r0, dr  from mask test */
	1.14,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200101092029",  "gain_1.200101092029" } ,



       /* 37007, April 28, 2001, doy 118, 
	  New camera day, 
	  mask test day.
       */


       {37007.0375 ,          /* Valid juld range */
	37007.7160 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200104280054",  "gain_1.200104280054" } ,

       {37007.7167 ,          /* Valid juld range */
	37007.7750 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200104281712",  "gain_1.200104281712" } ,

       {37007.7757 ,          /* Valid juld range */
	37007.8166 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	-1.1,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200104281837",  "gain_1.200104281837" } ,

       /* 37007, April 28, 2001, doy 118, 
	  MKIV COMMENT: Sat Apr 28 19:36:41 GMT 2001
	                Pausing to correct barrel azimuth.
       */

       {37007.8167 ,          /* Valid juld range */
	37007.9833 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200104281837",  "gain_1.200104281837" } ,

       {37007.9840 ,          /* Valid juld range */
	37007.9868 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200104282337",  "gain_1.200104282337" } ,

       {37007.9875 ,          /* Valid juld range */
	37010.7236 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200104282342",  "gain_1.200104282342" } ,




       /* May 1, 2001, doy 121 */
       {37010.7243 ,          /* Valid juld range */
	37013.7771 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200105011723",  "gain_1.200105011723" } ,

       /* May 4, 2001, doy 124 */
       {37013.7778 ,          /* Valid juld range */
	37013.7931 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200105041840",  "gain_1.200105041840" } ,

       /* May 4, 2001, doy 124 */
       {37013.7937 ,          /* Valid juld range */
	37189.8021 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200105041903",  "gain_1.200105041903" } ,
	
       /* Oct 27 19:16:03 GMT 2001, doy 300 
	  Regular mk4 opal was replaced with the spare. 
       */
       {37189.8028 ,          /* Valid juld range */
	37208.8833 ,
	13.5       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200105041903",  "gain_1.200105041903" } ,
	
       /* Nov 15 21:13:00 GMT 2001, doy 319 
	  Spare mk4 opal was replaced with the regular. 
       */
       {37208.8840 ,          /* Valid juld range */
	37286.7840 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200105041903",  "gain_1.200105041903" } ,
	
       /* Feb 01 2002, doy 32
	  a series of cal corrects were done to debug
	  a pB increase as a function of tod.
       */
       {37286.7847 ,          /* Valid juld range */
	37286.8326 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200202011850",  "gain_1.200202011850" } ,
	
       {37286.8333 ,          /* Valid juld range */
	37286.8694 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200202012000",  "gain_1.200202012000" } ,
	
       {37286.8701 ,          /* Valid juld range */
	37286.9083 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200202012053",  "gain_1.200202012053" } ,
	
       {37286.9090 ,          /* Valid juld range */
	37510.7639 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200202012149",  "gain_1.200202012149" } ,
	
       {37510.7653 ,          /* Valid juld range */
	37605.7667 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200209131822",  "gain_1.200209131822" } ,
	
       {37605.7674 ,          /* Valid juld range */
	37864.8847 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200212171825",  "gain_1.200212171825" } ,

       {37864.8854 ,          /* Valid juld range */
	40000.0000 ,
	13.8       ,          /* Bopal */
	0.84738906 ,          /* trt */
	0.01641    ,          /* fpt */
	-9999.0    ,          /* IDspare */
	1.0,                  /* kappa */
	2.85,                 /* BarrelOffset */
	103.661,  275.671,    /* hairspots from data near mask test */
	0.938592, 0.00526475, /* r0, dr  from mask test */
	1.10,     2.85,       /* goodRmin, goodRmax in Rsun */
	0.,       9.,         /* pixels between which to estimate the bias */
	376.0   ,             /* ZeroSky */
	1.00    ,             /* VenusCalFac */
	1.0     ,             /* ExtraCalFac */
	2.5     ,             /* DiffractFac */
	40      ,             /* DiffractPix */
	192     ,             /* PhiPix */
	40      ,             /* PolarityCkPix */
	35 , 365,             /* NegPix[2] */
	20 ,  34,             /* WrapPix[2] */
	340,  370,            /* RingSearch[2] */
	300,                  /* RingFixPix    */
	"gain_0.200309022115",  "gain_1.200309022115" } 
	
    };

