/*  The raw header and data format of the mk4 data as
    collected at MLSO.
    It is modeled after the mk3 header and data format.

    Set up by Alice Lecinski in fall of 2001.
    It is nearly identical to the header file written
    by Jay Chalmers for mk3 data in 1986.

    I strongly suggest *not* editting this code at all, unless
    you are absolutely sure you've found an error that
    needs fixing.

    If you edit it, you risk destroying the integrity of the
    code.  So if you do edit it, insure results pre and post
    actually match.


*/

#define RECSZ   (1184)   /* 1184*2 = 2368  */

/*     Each mk4 record begins with a 32 word header.

 0.)  IGNORE.
 1.)  IGNORE. Logical unit number of tape drive.
 2.)  Sky Brightness. 
 3.)  Compressed data flag. 1 -> 2776 words comprising 8 std records CONSTANT
 4.)  Low Barrel Limit. integer with 16384 == 360 deg. CONSTANT
 5.)  High Barrel Limit. " Changed to +-184. deg. on doy 75 '80. CONSTANT
 6.)  Time of day msw (most significant word). In Hz. i.e. 216000/hour. CONSTANT
 7.)  Time of day lsw (least signif. word).     "
 8.)  Day Of Year CONSTANT
 9.)  Year - 1900 CONSTANT
10.)  Barrel Angle. same units as limit.
11.)  IGNORE.
12.)  Time of record in Hz since start of scan.
13.)  Barrel scan speed. 13 -> ~1300 recs/scan, 12 | 14 -> ~660 CONSTANT
14.)  P Angle in min. CONSTANT
15.)  Tilt plate. 0 | 150 -> calibration, 1000 -> normal CONSTANT
16.)  IGNORE. Real-time tape errors
17.)  IGNORE. Re-read tape errors
18.)  IGNORE. Re-write tape errors
19.)  rec_no  For record 0 this contains the total # of recs in the image.
20.)  IGNORE.
21.)  Not Used.
22.)  Not Used.
23.)  Not Used.
24.)  Not Used.
25.)  Not Used.
26.)  Not Used.
27.)  Not Used.
28.)  Not Used.
29.)  IGNORE.
30.)  Not Used.
31.)  Not Used.

The normal record consists of this 32 word header, followed by one
channel consisting of records of 384*3 words of the form
	i1 q1 u1 i2 q2 u2 ... i383 q383 u383

*/

struct tapehead { short
jnk0,
lunit,		/* IGNORE. Logical unit number of tape drive.		      */
sky,		/* Sky Brightness.         				      */
comprs,		/* Compressed data flag. 1 is comprsed true, 0 is uncomprs    */
		/* If compressed, expect   -> 2776 wds 8 std records CONSTANT */
       		/* If uncompressed, 32 + 3*3*128 = 1184  16-bit words         */
low_limit,	/* Low Barrel Limit. integer with 16384 == 360 deg. CONSTANT  */
high_limit,	/* High Barrel Limit.  deg. on doy 75 '80. CONSTANT	      */
tod_msw,	/* Time of day msw (the top 16bits of a 32bit entity) CONSTANT*/
tod_lsw,	/* Time of day lsw. ( the lowest 16 bits of the time) CONSTANT*/                /* The time of day is in Hertz, where 216000 = 1 hour         */
doy,		/* Day Of Year CONSTANT					      */
yr,		/* Year - 1900 CONSTANT					      */
b_ang,		/* Barrel Angle. same units as limit.			      */
jnk1,
scan_time,	/* Time of record in Hz since start of scan.		      */
scan_speed,	/* Barrel scan speed.	13 -> ~1300 recs/scan,
					12 | 14 -> ~660 CONSTANT	      */
P_ang,		/* P Angle in min. CONSTANT				      */
tilt,		/* Tilt plate. 0 | 150 -> calib, 1000 -> nrml CONSTANT	      */
rtte,		/* Real-time tape errors				      */
rte,		/* Re-read tape errors					      */
wte,		/* Re-write tape errors					      */
rec_no,		/* For record 0 this contains the total # of recs in the img. */
jnk2[12]; } ;

typedef struct tapehead * (TH);   /* TH is a pointer to a structure tapehead. */




#ifdef START
    struct tapehead  thead;
#else
    extern struct tapehead  thead;
#endif
