/* mk4map.c
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Mark-4 Synoptic Map generator.
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * For source code comments, see "/home/cordyn/mk4/syn/readme.h".
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Author: Alice Lecinski   HAO/NCAR   mkamap.c [Mk3]
 * Updates: Andrew L. Stanger   25 Oct 1999
 * 25 Oct 1999: Adapt for Mk4.
 * 17 Oct 2002: Adapt for Mk4 version 2 calibration software.
 * 18 Nov 2002: Modify output file names.
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */

#define START
#include "/home/cordyn/mk4/syn/readme.h"

#include <stdio.h>
#include <ctype.h>
#include "/home/cordyn/mk4/syn/EWmap4.h"
#include "/home/cordyn/mk4/src/mk4v2.h"
#include "/home/cordyn/mk4/src/mk4headv2.h"

#define CYSIZE (720*384)	/* size of cylindrical array */
#define BASIZE (720)		/* size of bangle array */
#define BKWDS  (1200)		/* Bytes to skip backwards from the EOF */

char	atime [300];
char	EWmapnm [80], mapnm [80], EWpath [80] ;
char	fmapname [80] ;
char	smapname [80] ;
char	(*filenm)[300] ;
char	(*filenmba)[300] ;
char	ims_avail [10000] ;
char	explanation [] = "\
\n\
Date      Doy     hr_min_sec   East long  West long  CentM long  used?(y or n)\n";
char	*piceos;

short	*pBim;			/* pB image buffer (short). */
short	*pba,  ba  [NAZ] ;	/* barrel angles buffer (short). */
short	*sy, sbuf [360] ;
short	Bmap  [MLATS][BLONGS], imap [MLATS][LONGS] ;
short	BCmap [ PA  ][BLONGS], cmap [ PA  ][LONGS] ;

float	pB [DAYS][LATS] ;
float   Elong [100], Wlong [100], Clong [100] ;  /* <-- This is where the 
					     program can easily bomb, if the 
					     dimension is not large enough. */
float *pfba, fba [NAZ];		/* barrel angles buffer (float). */

int	Crot, numSfiles ;
int	doyflag, Neflag, cal0flag, timeflag ;
int     chanflag, channel;
int	east, west, map, EWmap, CMmap ;
int     Fbdoy, Fedoy, Fbyr, Feyr, Fleap ;
int     iCR, bdoy, edoy, byr, eyr, leap ;
int	ibdoy, iedoy, ibyr, ieyr;
int     idflag, udflag, qdflag, pBflag, posflag, negflag ;
int	isavg;
int	local ;
int     mon, day, year,doy;
int	num_ims_avail, num_lines ;
int	offset = 60 ;
int     orignray;
int     Rngflag, dayflag, quickflag, nameflag;
int	Secflag, cal15flag, chnme;
int     sclmin, sclmax;
int	num_ims_avail, num_lines ;
int	useyn = 1 ;

long    aspot;
long    iFbegEj, iFendEj, iFbegWj, iFendWj ;
long    ibegEj,  iendEj,  ibegWj,  iendWj, ibegCj, iendCj ;

float   INTERPDAY;
float	flbdoy, fledoy;
float	height = 0.0 ;
float   thetamin, thetamax;
float   pixscl, r0 = 0.868213, dr = 0.005464;    /* 31 March 2000  */

double  begEj, endEj, begWj, endWj, begCj, endCj ;
double  slopeE, slopeW, slopeC ;
double  thoff, twopi;

/* -------------------------------------------------------------------------- */

main (argc, argv)

int argc;
char *argv [];
{

    extern int isleap () ;
    extern int readmk4head () ;
    extern int readmk4 () ;

    int  do_ask () ;
    int nmdates () ;

    void prsum () ;
    void get_slopes (), ck_get_day (), ck_get_long ();
    void do_EWmapnm (), do_mapnm ();
    void fillEmap  (), fillWmap  ();
    void fillEfile (), fillWfile ();
    void do_mapout (), do_fileout (), do_usedout ();
    void fdo_mapout () ;
    void fill_ims_avail ();

    FILE *infid, *fid;

    register long ii;
    register char *w;
    register float *fp;

    static char ss [100], name [100][300] ;
    static char syear [8] ;
    static char limb [4] = "TBD" ;
    static char name_east [4] = "E" ;
    static char name_west [4] = "W" ;

    int ask;
    int eday, wday ;
    int ix, iy ;
    int filecnt ;
    int howfar ;
    int ie, iw, ic ;
    int kyear, kmonth,  kday ;
    int khour, kminute, ksecond ;
    int rpix ;
    int who ;
    int yrfix ;

    float elong, wlong, clong ;
    float opalcor = 1.556873 ;
    float scaleinv = 1.0 ;
    static float fmap [MLATS][LONGS] ;
    static short smap [MLATS][LONGS] ;

    double f_juld ;
    double dpangle, dbangle, drsun ;

    INTERPDAY = 1.5; 
    ask = 0 ;
    map = 0 ; 
    EWmap = 1 ;				/* History maps are the default. */
    west = east = 0 ;
    num_ims_avail = 0 ;
    num_lines = 1 ;
    twopi = pi + pi;

    sprintf (ims_avail, explanation);
    filenm = name ;

    fp = &pB [0][0] ;
    for( ii = 0 ; ii < DAYS * LATS ; ii++ ) *fp++ = -9999.000000 ;

    /*** Process command line arguments. ***/

    if ( argc <= 1 ) { prsum () ; exit (3) ; }

    while (--argc)
	{
	if (*(w = *++argv) == '-')	/* Check for flag arguments */
	    switch (w [1])
	    {
	    case 'a':   ask++;	 /* Ask whether or not to use a longitude. */
			break ;

	    case 'i':   sprintf (ss, "%s", *(++argv) );  
			sscanf  (ss, "%f", &INTERPDAY);
			argc -= 1 ;
			break ;

	    case 'e':   east++;	 /* East limb map */
/*
 *			sprintf (limb, "%s", name_east) ;
 */
			break ;

	    case 'w':   west++;	 /* West limb map */
/*
 *			sprintf (limb, "%s", name_west) ;
 */
			break ;

	    case 'c':   CMmap++; /* Make a file of pB data, 
				  * LONGSxPA  (360x360) beginning at central
				  * meridian passage.
				  */
			break ;

	    case 'm':   map++;	 /* Make a file containing a synoptic map of
				  * the pB data, LONGSxMLATS short ints 
				  * suitable for the Grinnell
				  */
			break ;

	    case 'h':   sprintf (ss, "%s", *(++argv) );  
			sscanf  (ss, "%f", &height );
			argc -= 1 ;
			break ;

	    case 'l':   local++; /* Make the map in the present directory
				  * instead of in the map library.
				  * This only works when "map" is requested.
				  */
			break ;

	    case 'r':		 /* Get the rotation to create. */
			sprintf (ss, "%s", *(++argv) );  
			sscanf  (ss, "%d", &Crot );
			argc -= 1 ;
			break ;

	    default:    fprintf (stderr, " unknown flag %s\n",*argv);
		        prsum (); exit (1);
	    }
	else		/*** Get filenames. ***/
	    {
	    if (*w == '?') { prsum (); exit (2); }
	    sprintf ((char *) filenm++, "%s", w);
	    break;
	    }
	}

    /*** Set defaults. ***/

    if (east + west == 0)  east++ ;
    if ( map )			    EWmap = 0 ;
    if (CMmap) {east = west = map = EWmap = 0 ; }

    printf ("\n") ;
    printf ("east: %d  west:  %d\n", east, west) ;
    printf ("map:  %d  CMmap: %d  EWmap: %d\n", map, CMmap, EWmap) ;

    if (height <= 0)
	{
	height = 1.3;
	fprintf (stderr, "\nUsing 1.3 Rsun\n");
	}

    /* Determine which dates and pB images are needed
     * to make the desired maps for this rotation.
     */

    filenm = name ;

    /*** nmdates fills up the files in filenm and gets numSfiles ***/

    if ( !nmdates (Crot, argv, argc) )
	{
	fprintf (stderr, "Couldn\'t load the images for the synoptic map.\n"); 
	exit (-3) ;
        }

    fprintf (stderr,
	"\nFor rotation %d the following images will be read:\n",Crot);
    for ( filenm = name, filecnt = 1; filecnt <= numSfiles; filecnt++ )
	{
	fprintf (stderr, "\t%s\n", *filenm++) ;
        }

    fprintf (stderr,
    "\nFor fake \"history data\", the file beginning and ending days are:\n\
    Fbdoy -> %d, %d  Fedoy %d, %d \n",Fbdoy, Fbyr, Fedoy, Feyr ) ;

    fprintf (stderr,
    "\nFor map data, the map beginning and ending days are:\n\
    bdoy -> %d, %d   edoy %d,  %d\n\n",bdoy, byr, edoy, eyr ) ;

    ibyr = (int) byr;
    ieyr = (int) eyr;
    if (ieyr > ibyr) yrfix = 365 + isleap (ibyr);
    else             yrfix =   0;
    ibdoy = (int) (flbdoy * 100);
    iedoy = (int) ((fledoy - (float) yrfix) * 100);

    /*** Create the output map name. ***/

    if (EWmap) do_EWmapnm (Crot, height);
    if (map || CMmap) do_mapnm (Crot, height) ;

    sprintf (fmapname, "%s.df", mapnm) ;
    sprintf (smapname, "%s.ds", mapnm) ;

    get_slopes () ;	/* Get the slopes to convert from day to longitude. */

    /*** Image file loop. ***/

    for ( filenm = name, filecnt = 1; filecnt <= numSfiles; filecnt++ )
	{
        readmk4head (filenm, mk4h, 0) ;		/* Read Mk4 header. */

	/*** Print out the summary information. ***/

	fprintf (stderr, "\nFile: %s\n", filenm);
	fprintf (stderr, "  Juld:%d  Time:%d\n",
		 mk4h->Image.Juld, mk4h->Image.Time) ;
/*
 *	fprintf (stderr, "prday: %s\n", prday (mk4h->Image.Juld)) ;
 */
        fprintf (stderr, "  obstype: %d  datatype: %d  procsteps:%d \n",
                 mk4h->ObsType, mk4h->DataType, mk4h->ProcSteps);

        if (mk4h->DataType != IS_q || mk4h->ProcSteps != IS_cal_avg ||
	    mk4h->ObsType  != IS_coronal)
            {
	    fprintf (stderr,"mk4syn> This image is NOT pB data.\n") ;
            exit (-5);
	    }
        
	/*** Read Mk4 image. ***/

	pBim = (short *) malloc (mk4h->Xdim * mk4h->Ydim * sizeof (short)) ;

	readmk4 (filenm, mk4h, pBim, 0) ;	/* Read Mk4 header & image. */

	pixscl = mk4h->pixscl ;
	r0 = (mk4h->r0) ;
	dr = (mk4h->dr) ;

        /*** Compute P-angle, B-angle, Rsun (arcsec). ***/

/*
 *	kyear   = mk4h->Image.Year   ;
 *	kmonth  = mk4h->Image.Month  ;
 *	kday    = mk4h->Image.Day    ;
 *	khour   = mk4h->Image.Hour   ;
 *	kminute = mk4h->Image.Minute ;
 *	ksecond = mk4h->Image.CentiSec * 10 ;
 *
 *	pb0r (kyear, kmonth, kday, khour, kminute, ksecond,
 *	      &dpangle, &dbangle, &drsun) ;
 */

/*
 *        printf ("r0 [960]: %12.6f   dr [960]: %12.6f\n", r0, dr) ;
 */

	/*** Adjust r0 & dr for actual Earth-Sun distance. ***/
	/*** No longer needed, since this is now done by "rawt4v2.c". ***/
/*
 *	r0 *= 960.0 / drsun ;
 *	dr *= 960.0 / drsun ;
 */

/*
 *	printf ("r0 [adj]: %12.6f   dr [adj]: %12.6f\n", r0, dr) ;
 */

	/*** Compute pixel corresponding to specified height. ***/

        rpix = (int) ( 0.5 + (( height - r0 ) / dr )) ;
        fprintf (stderr, "height %.3f Rsun  pixel: %3d [r0: %.6f dr: %.6f Rsun]\n",
                 height, rpix, r0, dr);

	if (mk4h->Xdim == NAZ)			/* Spline-fitted image. */
	    {
	    pfba = fba;
	    for (ii = 0; ii < (long)(mk4h->Xdim); ii++)
		{ 
		*pfba = (float) (ii) * 0.5000 ;
		pfba++;
		}
	    }
        else
	if (mk4h->Xdim != NAZ)			/* Non-spline-fitted image. */
	    {
	    fprintf (stdout, "Xdim (%d) != %d\n", mk4h->Xdim, NAZ) ;
	    thoff = 30.0 * d2r - pangle (mk4h->Pangle);

	    dopicnm (mk4h); 		/* Create the .ba filename. */
	    howfar = IS_raw ;
	    who    = IS_ba ;
	    dofnm (who, howfar); 

	    /*** Open Barrel Angle file & read barrel angles. ***/

	    if (! (infid = fopen (picnm, "r")) )
		{
		sprintf (ss, "/puu/mk4/mk4_best/%s", picnm);
		sprintf (picnm, "%s", ss);
		if (! (infid = fopen (picnm, "r")) )
		    {
		    fprintf (stderr, "Can\'t find %s for the b-angles.\n",
			     picnm);
		    exit (1);
		    }
	        }

	    printf ("\tOpening: %s\n", picnm);
	    fseek (infid, 0, 0);
	    fread (ba, 1, (mk4h->Xdim) * 2, infid);
	    fclose (infid);
	    pba = ba; pfba = fba;

	    for (ii = 0; ii < (long) (mk4h->Xdim); ii++)   /* Convert to PA */
		{
		*pfba = (float) (ba2rad * ((double) *pba) + thoff + twopi);
		if( *pfba > (float) (twopi) ) *pfba -= (float) (twopi);
		*pfba *= r2d;			/* Convert to degrees. */
		pfba++; pba++;
	        }
	    }
/*
 *      else
 *	    {
 *	    fprintf (stdout, "Nray (%d) != %d\n", mk4h->Nray, NAZ) ;
 *	    exit (-6) ;
 *	    }
 */

	/* Is this a time we need for the east or west map ?  */
	/* If so, return the appropriate longitude for the right map.*/

	ck_get_day  (mk4h->Image.Juld, mk4h->Image.Time,
		     &eday, &wday, &f_juld) ;

	ck_get_long (mk4h->Image.Juld, mk4h->Image.Time,
		     &elong, &wlong, &clong, &f_juld) ;

	printf ("eday: %3d  wday: %3d  f_juld: %f\n", eday, wday, f_juld) ;
	printf ("elong: %7.2f  wlong: %7.2f  clong: %7.2f\n",
		 elong, wlong, clong) ;
	fflush (stdout) ;

	/*** Proceed if this image belongs in the specified synoptic map. ***/

	if ((elong >= -999) || (wlong >= -999) || (clong >= -999) ||
	    (eday  >= -999) || (wday >= -999) )
            {

	    /*** Do azimuthal scan at specified height. ***/
	    /*** Put data into a 1-D latitude array. ***/

	    sy = sbuf ;
	    mk4_azscan (sbuf, pBim, fba, mk4h->Xdim, rpix) ;

	    printf ("after mk4_azscan\n") ;
	    fflush (stdout) ;

	    /*** Put this in the correct part of the correct map. ***/

            if (!ask || (ask && (useyn =
		do_ask (&mk4head, eday, wday, elong, wlong, clong, f_juld))))
                {
	        printf ("after do_ask\n") ;
	        fflush (stdout) ;
		sy = sbuf ;
		if (map || CMmap)
		    {
		    if (east && elong >= -999 )
			{ 
			fillEmap (Bmap, sy, elong, f_juld);

			printf ("ie: %3d\n", ie) ;
			fflush (stdout) ;

			Elong [ie++] = elong ;

			printf ("Elong [%d]: %f\n", ie, Elong [ie]) ;
			fflush (stdout) ;
			printf ("ie: %3d\n", ie) ;
			fflush (stdout) ;
	                printf ("after fillEmap\n") ;
	                fflush (stdout) ;
			}
		    if (west && wlong >= -999 )
			{ 
			fillWmap (Bmap, sy, wlong, f_juld);
			Wlong [iw++] = wlong ;

			printf ("Wlong [%d]: %f\n", iw, Wlong [iw]) ;
			fflush (stdout) ;
	                printf ("after fillWmap\n") ;
	                fflush (stdout) ;
			}
		    if (CMmap && clong >= -999)
			{
			fillCmap (BCmap, sy, clong, f_juld);
			Clong [ic++] = clong ;
			}
		    }

		sy = sbuf ;
		if (EWmap)
		    { 
		    if (east && eday >= -999) fillEfile (pB, sy, eday) ;
		    if (west && wday >= -999) fillWfile (pB, sy, wday) ;
		    }
	        }

	    if ((eday + wday > -2 * 9990 ) || 
		(elong + wlong + clong > -3.0 * 9990.0 )) 
		fill_ims_avail (&mk4head, elong, wlong, clong, f_juld);

	    printf ("after fill_ims_avail\n") ;
	    fflush (stdout) ;
	    }

	filenm++;
	free (pBim) ;
        }

    /* All the data for the Carrington rotation has been accumulated.
     * Write it to disk.
     */

    if (EWmap) do_fileout (EWmapnm, EWpath) ;
    if (map || CMmap)
	{

	/*** First interpolate the map. ***/

	if  (east || west)
	    {
	    if (east) terpimap (Elong, ie, imap, Bmap, MLATS) ;
	    else      terpimap (Wlong, iw, imap, Bmap, MLATS) ;

	    /*** Apply opal correction. ***/
	    /*** No longer needed. Done by v2 calibration. ***/
/*
 *	    for (iy = 0; iy < MLATS; iy++)
 *		for (ix = 0; ix < LONGS; ix++)
 *		    {
 *		    imap [iy][ix] *= opalcor ;
 *		    }
 */

	    /* Convert to pB [Bsun] units. */

	    printf ("\nConvert to pB [Bsun] units  scale: %8.2e  offset: %8.2e\n",
		   mk4h->data_scale, mk4h->data_offset) ;

	    scaleinv = 1.0 / mk4h->data_scale ;
	    printf ("scaleinv: %8.2e\n", scaleinv) ;

	    /* subtract data_offset. */

	    for (iy = 0; iy < MLATS; iy++)
		for (ix = 0; ix < LONGS; ix++)
		    {
		    smap [iy][ix] = imap [iy][ix] - mk4h->data_offset ;
		    fmap [iy][ix] = (float) (smap [iy][ix]) * scaleinv ;
		    }

	    /*** Write synoptic map to a disk file. ***/

	    do_mapout  (smapname,  smap, MLATS) ;
	    fdo_mapout (fmapname, fmap, MLATS) ;
	    }
	else		/* CMmap */
	    {
	    terpimap (Clong, ic, cmap, BCmap, PA) ;
	    do_mapout (smapname, cmap, PA) ;
	    }

	/*** Append C.R. information to end of synoptic map file. ***/
	/*** Beginning DOY & Year, Ending DOY & Year. ***/

	/*** Short integer map. ***/

	if ((fid = fopen (smapname, "a+")) == NULL )
	    {
	    fprintf (stderr, "\nError in opening the file - %s \n", smapname) ;
	    exit (-1) ;
	    }

/*
 *	printf ("limb: %s\n", limb) ;
 *	fflush (stdout) ;
 */

	fwrite (&ibdoy, 1, sizeof (int),  fid);
	fwrite (&ibyr,  1, sizeof (int),  fid);
	fwrite (&iedoy, 1, sizeof (int),  fid);
	fwrite (&ieyr,  1, sizeof (int),  fid);
/*
 *	fwrite (&Crot,  1, sizeof (int),  fid);
 *	fprintf (fid, "%4s", limb);
 */
	fclose (fid);

	do_availout (smapname, ims_avail, num_ims_avail, num_lines);

	/*** Floating point map. ***/

	if ((fid = fopen (fmapname, "a+")) == NULL )
	    {
	    fprintf (stderr, "\nError in opening the file - %s \n", smapname) ;
	    exit (-1) ;
	    }

/*
 *	printf ("limb: %s\n", limb) ;
 *	fflush (stdout) ;
 */

	fwrite (&ibdoy, 1, sizeof (int),  fid);
	fwrite (&ibyr,  1, sizeof (int),  fid);
	fwrite (&iedoy, 1, sizeof (int),  fid);
	fwrite (&ieyr,  1, sizeof (int),  fid);
/* 
 *	fwrite (&Crot,  1, sizeof (int),  fid);
 *	fprintf (fid, "%4s", limb);
 */
	fclose (fid);

	printf ("ibdoy: %3d  ibyr: %4d  iedoy: %3d  ieyr: %4d\n",
	       ibdoy, ibyr, iedoy, ieyr) ;

	do_availout (fmapname, ims_avail, num_ims_avail, num_lines);
    }
}

/* -------------------------------------------------------------------------- */

/* Compute the slopes for the conversion from day to longitude. */

void
get_slopes ()

{
    slopeE = 360.0  / ( endEj - begEj )  ;
    slopeW = 360.0  / ( endWj - begWj )  ;
    slopeC = 360.0  / ( endCj - begCj )  ;
}

/* -------------------------------------------------------------------------- */

void
prsum ()

{
    static char help1[] = "\
\n\
mk4syn [-a] [-i nday] [-cm] [-m] [-l] [-e] [-w] [-h height] [-r Crotation] [image1 ... imageN]\n\
\n\
Example:              cat imlist | mk4syn -e -h 1.3 -r 1776 \n\
\n" ;

    static char help2[] = "\
Flags	Description\n\
-----	-----------\n\
-[a]	    Have the program ask whether or not to use a longitude\n\
-[i nday]   Number of days over which to interpolate (default: 1.5 days).\n\
-[cm]       Make an array of shorts pB[360][360] (pB[PA][longs] longs goes \n\
	    fastest) that begins at Central Meridian passage \n\
-[m]        Make a map of short pB[181][360], suitable for the Grinnell\n\
-[l]        If -m is specified, -l will make the map locally (current directory) \n\
-[e]        Make an east limb map (default).\n\
-[w]	    Make a  west limb map.\n\
-[h height] Height in Rsun of the map (default, 1.3 Rsun).\n\
-[r Crot]   Carrington rotation of the map to create.\n\
\n" ;

    fputs (help1, stderr);
    fputs (help2, stderr);
}

/* -------------------------------------------------------------------------- */

char query [] = "\
East longitude is %.1f\nWest longitude is %.1f\nCent Meridian long is %.1f\n\
	Do you want to use this data? (y or n) --> \
" ;


/* -------------------------------------------------------------------------- */

do_ask (filehd, eday, wday, elong, wlong, clong, juld) 

register FH filehd;  
int eday, wday ;
float elong, wlong, clong ;
double juld ; 
{
    char   ans [8] ;
    extern int jdate (), iday () ;

    if ( (eday  + wday          > -2   * 9990   ) ||
        ( elong + wlong + clong > -3.0 * 9990.0 ) )
	{
	jdate ( (long) juld, &mon, &day, &year ) ;  
	doy = iday (mon, day, year) ;

	fprintf (stderr, "\n%d  Doy --> %d;  %d \n",
		filehd->Image.Juld, doy, filehd->Image.Time) ;

	fprintf (stderr, query, elong, wlong, clong) ;

	scanf ("%s", ans) ;
	if ( ans [0] == 'y' )  return (1) ;
	else                   return (0) ;
        }
    else                       return (0) ;
}

/* -------------------------------------------------------------------------- */
