/* do_out.c
 *------------------------------------------------------------------------------
 * do_mapout
 * do_availout
 * do_fileout
 *------------------------------------------------------------------------------
 * Author:  Alice Lecinski   HAO/NCAR    3 Nov 1997
 * Updates: Andrew Stanger   HAO/NCAR   14 Mar 2002
 * 14 Mar 2002: adapt for Mk4.
 *  6 Nov 2002: Add fdo_mapout ().
 *------------------------------------------------------------------------------
 */

#include <stdio.h>
#include <ctype.h>
#include "/home/cordyn/mk4/syn/EWmap4.h"
#include "/home/cordyn/mk4/syn/ephemeris.h"

/* Time goes in the forward direction. */
/* Arrays are arranged so latitude "goes" fastest. */

extern short imap [MLATS][LONGS];/* East and West maps go from north to south */
extern float pB [DAYS][LATS] ;   /* East file goes from north to south
			  	  * West file goes from south to north
				  */
extern int   iCR ;
extern int   east, Fleap, Fbyr, Fbdoy, Feyr, Fedoy ;
extern float height ;

extern char  explanation [];

FILE *fid ;

/* -------------------------------------------------------------------------- */

/*** Write synoptic map 2D float array to output file. ***/

fdo_mapout (outfile, fltmap, numjj) 

    char outfile [] ;
    float *fltmap ;
    int numjj ;
{
    if ((fid = fopen (outfile, "w")) == NULL )
	{
	fprintf (stderr, "\nError in opening the file - %s \n", outfile) ;
	exit (-1) ;
        }

    fwrite (fltmap, sizeof (float), LONGS*numjj, fid) ;
    fclose (fid) ;

    return (0) ;
}

/* -------------------------------------------------------------------------- */

/*** Write synoptic map 2D short array to output file. ***/

do_mapout (outfile, smlmap, numjj) 

    char outfile [] ;
    short *smlmap ;
    int numjj ;
{
    if ((fid = fopen (outfile, "w")) == NULL )
	{
	fprintf (stderr, "\nError in opening the file - %s \n", outfile) ;
	exit (-1) ;
        }

    fwrite (smlmap, sizeof (short), LONGS*numjj, fid) ;
    fclose (fid) ;

    return (0) ;
}

/* -------------------------------------------------------------------------- */

/*** Append ASCI footer to the synoptic map file. ***/

void
do_availout (outfile, imsavail, Nimsavail, Nlines)

    char outfile [], imsavail [];
    int  Nimsavail, Nlines ;
{
    if ((fid = fopen (outfile, "a+")) == NULL )
	{
	fprintf (stderr, "\nError in opening the file - %s \n", outfile) ;
	exit (-1) ;
        }

    fprintf (fid, "%s", imsavail);
    fprintf (fid, "%s\n", explanation);
    fprintf (fid, "Number of images available: %d\n", Nimsavail);
    Nlines += 5 ;
    fprintf (fid, "Number of lines to \"tail\" : %d\n", Nlines);
    fclose (fid) ;
}

/* -------------------------------------------------------------------------- */

/*** History map output. ***/

do_fileout (outfile, path)

char *outfile, path [] ;
{
    int      kk, i ;
    int	     CR, YR ;
    float    CRB, CRE, LIMB, HEIGHT, INC ;

    int      yrs, days ;
    float    cmday ;

    cmday =  CRtable [iCR][1] ;

    CR = (int) CRtable [iCR][0] ; YR = (int) CRtable [iCR][2] - 1900;
    HEIGHT = height ;
    INC = 5.0 ;

    /* Neither CRB or CRE are actually the TRUE beginning of the
     * east (or west) limb rotation.  But the calculation was kept
     * for historical reasons... Sorry!
     */

    if ( east )
	{
	CRB = cmday - 6.82 ;
	CRE = cmday - 6.82 + 27.3 ;
	LIMB = EAST ;
        }
    else
	{
	CRB = cmday + 6.82 ;
	CRE = cmday + 6.82 + 27.3 ;
	LIMB = WEST ;
        }

    if ( CRB < 1 ) { CRB += 365 + Fleap ; YR -= 1 ; }
    if ( CRE > (365 + Fleap) ) CRE -= 365 + Fleap ;

	
    if ((fid = fopen (outfile, "w")) == NULL )
	{
	mkdir (path) ;
	chmod (path, 0777);
	if ((fid = fopen (outfile, "w")) == NULL )
	    {
	    fprintf (stderr, "\nError in opening the file - %s \n", outfile) ;
	    exit (-1) ;
	    }
        }
    fprintf (fid, "%d.0 %d.0 %.2f %.2f %.1f %.1f %.1f 0.0\n", 
	     CR, YR, CRB, CRE, LIMB, HEIGHT, INC ) ;

    for ( kk = 0 ; kk < DAYS ; kk++ )
	{

	yrs = Fbyr - 1900 ;
	days = Fbdoy + kk ;
	if (days > 365 + Fleap) { days -= 365 + Fleap ; yrs++ ; }
	if ( pB [kk][0] <= -9000.0 ) yrs = 0 ;

	fprintf (fid, "\
 I =    0  SERNUM =    0  DATE =      0  HEIGHT =  1.300  YEAR =   %2d  DAY =  %3d  MM =         0\n", yrs, days ) ;

	for ( i = 0 ; i < 32 ; i+=8 )
	    {
	    fprintf (fid, "%9.3f%9.3f%9.3f%9.3f%9.3f%9.3f%9.3f%9.3f\n", 
		pB [kk][i+0], pB [kk][i+1], pB [kk][i+2], pB [kk][i+3], 
		pB [kk][i+4], pB [kk][i+5], pB [kk][i+6], pB [kk][i+7] ) ;
	    }
	fprintf (fid, "%9.3f%9.3f%9.3f%9.3f%9.3f\n", 
	    pB [kk][i+0], pB [kk][i+1], pB [kk][i+2], pB [kk][i+3], 
	    pB [kk][i+4] ) ;
        }

    if ( yrs != 0 && ((yrs != Feyr - 1900) ||  (days != Fedoy)) )
	{
	fprintf (stderr, "\007 There is an error in the ending days\n\n");
	fprintf (stderr, "yrs %d Feyr %d --- days %d Fedoy %d\n", 
		 yrs, Feyr, days, Fedoy) ;
        }

    fclose (fid) ;

    return (0) ;
}

/* -------------------------------------------------------------------------- */

