/* fill.c
 *------------------------------------------------------------------------------
 * Fill synoptic may arrays.
 *
 * fillEmap ()
 * fillWmap ()
 * fillCmap ()
 * fillEfile ()
 * fillWfile ()
 * get_El_fix ()
 *------------------------------------------------------------------------------
 * Author:  Alice Lecinski   HAO/NCAR    3 Nov 1997   Mk3
 * Updates: Andrew Stanger   HAO/NCAR   12 Mar 2002
 * 14 Mar 2002: adapt for Mk4.
 *------------------------------------------------------------------------------
 */

#include <stdio.h>
#include <ctype.h>
#include "/home/cordyn/mk4/syn/EWmap4.h"

/* short BCmap [PA][BLONGS]; */ /*Position angle goes from north to south to
				  north, 0 to 359 degrees. */
			       /* BCmap is arranged so longitude "goes" 
				  fastest. */
/* short Bmap [MLATS][BLONGS];*//* East and West maps go from north to south */
				/* Bmap is arranged so longitude "goes"
				 * fastest. */

/* For both Bmap and BCmap (imap and cmap), longitude goes from
 * 0 to 360 degrees, with 0 degrees on the left and 360 degrees on the right.
 * Time is reversed, so that the earliest day is on the right,
 * and the latest day is on the left.
 * In idl, cmap can be displayed with:	a = intary (360, 360)
 *					tvscl, a, order=1
 * In idl, imap can be displayed with:	a = intary (360, 181)
 *					tvscl, a, order=1
 */

/* float pB [DAYS][LATS]  ; */	/* East file goes from north to south
				 * West file goes from south to north
				 * Time goes in the forward direction.
				 * pB is arranged so latitude "goes" fastest.
				 */
extern int offset ;		/* longitude offset between big & small map. */

double  El_beg = 2445061, El_lconst = 2445335, El_last = 2446796 ;
float   El_corr = 75, El_slope = 0.051335 ;
float   El_fix, get_El_fix() ;

/* pB units are 10^-10 B/Bsun for input data and for Bmap and imap */
/* pB units are 10^-10 B/Bsun for input data and for BCmap and cmap */
/* pB units for the EWfile are are 10^-8 B/Bsun */
    
/* -------------------------------------------------------------------------- */

fillEmap (bigmap, azscan, flong, f_juld) 

    short *bigmap;			/* Big synoptic map array. */
    short *azscan ;			/* Azimuthal scan. */
    float flong ;
    double f_juld ;
{
    int ilat, ilong ;
    short *big, *azp ;

    El_fix = get_El_fix (f_juld);	/* El Chicon fix. */

    ilong = (int) flong ;

    azp = azscan ;
    big   = bigmap ;

    for ( ilat = 0 ; ilat < MLATS ; ilat++ )	/* Fill Bmap North to South */
	{
	*(big + ilong + offset + ilat * BLONGS) = *azp + (short) El_fix ;
	azp++ ;
        }
    return (0) ;
}

/* -------------------------------------------------------------------------- */

fillWmap (bigmap, azscan, flong, f_juld) 

    short *bigmap;			/* Big synoptic map. */
    short *azscan ;			/* Azimuthal scan. */
    float flong ;
    double f_juld ;
{
    int ilat, ilong ;
    short *azp, *big ;

    El_fix = get_El_fix (f_juld) ;	/* El Chicon fix. */

    ilong = (int) flong ;

    azp = azscan ;
    big   = bigmap  ;

    *(big + ilong + offset + 0 * BLONGS) = *azp ;

    azp  = azscan ;
    azp += 359 ;

    for ( ilat = 1 ; ilat < MLATS ; ilat++ )	/* Fill Bmap North to South */
	{
	*(big + ilong + offset + ilat * BLONGS) = *azp + (short) El_fix ;
	azp-- ;				/* Reverse order. */
        }

    return (0) ;
}

/* -------------------------------------------------------------------------- */

fillCmap (bigmap, azscan, flong, f_juld) 

    short *bigmap;			/* Big synoptic map. */
    short *azscan ;			/* Azimuthal scan. */
    float flong ; double f_juld ;
{
    int pa, ilong ;
    short *azp, *big  ;  

    El_fix = get_El_fix (f_juld) ;	/* El Chicon fix. */
    ilong = (int) flong ;

    azp = azscan ;
    big   = bigmap ;

    for ( pa = 0 ; pa < PA ; pa++ )	/* Fill BCmap North to South to North */
	{
	*(big + ilong + offset + pa * BLONGS) = *azp + (short) El_fix ;
	azp++ ;
        }

    return (0) ;
}

/* -------------------------------------------------------------------------- */

fillEfile (fpB, azscan, iday)

float *fpB ;				/* Big synoptic map. */
short *azscan ;				/* Azimuthal scan. */
int iday ;				/* Day to insert. */
{

    int  ll, kk ;
    short *azp  ;  
    float  avg5 ;  

    /* pB data for east file goes from north to south. */

    azp = azscan ;

    ll = 0 ;
	{
	for ( kk=0, avg5=0; kk<3; kk++ )   {avg5 += (float) *azp ; azp++ ;}
	avg5 /= 3.0 ;			/* Average */
	*(fpB + iday * LATS + ll) = avg5 ;
        }

    for ( ll = 1 ; ll < 36 ; ll++ )
	{
	for ( kk=0, avg5=0; kk<5; kk++ ) {avg5 += (float) *azp ; azp++ ;}
	avg5 /= 5.0 ;			/* Average */
	*(fpB + iday * LATS + ll) = avg5;
        }

    ll = 36 ;
	{
	for ( kk=0, avg5=0; kk<3; kk++ ) {avg5 += (float) *azp ; azp++ ;}
	avg5 /= 3.0 ;			/* Average */
	*(fpB + iday * LATS + ll) = avg5;
        }

    return (0) ;
}

/* -------------------------------------------------------------------------- */

fillWfile (fpB, azscan, iday)

float *fpB ;				/* Big synoptic map. */
short *azscan ;				/* Azimuthal scan. */
int iday ;				/* Day to insert. */
{
    int ll, kk ;
    short *azp  ;  
    float avg5 ;  

    /* pB data for west file goes from south to north. */

    azp  = azscan ;
    azp += 180 ;

    ll = 0 ;
	{
	for ( kk=0, avg5=0; kk<3; kk++ ) {avg5 += (float) *azp ; azp++ ;}
	avg5 /= 3.0 ;			/* Average */
	*(fpB + iday * LATS + ll) = avg5;
        }

    for ( ll=1 ; ll<36 ; ll++ )
	{
	for ( kk=0, avg5=0; kk<5; kk++ ) {avg5 += (float) *azp ; azp++ ;}
	avg5 /= 5.0 ;			/* Average */
	*(fpB + iday * LATS + ll) = avg5;
        }

    ll = 36 ;
	{
	for ( kk=0, avg5=0; kk<2; kk++ ) {avg5 += (float) *azp ; azp++ ;}
	azp = azscan ;                    avg5 += (float) *azp ;
	avg5 /= 3.0 ;			/* Average */
	*(fpB + iday * LATS + ll) = avg5;
        }

    return (0) ;
}

/* -------------------------------------------------------------------------- */

float get_El_fix (f_juld)

double f_juld ;
{
    
    /* El Chicon fix in terms of 10^-10 B/Bsun */

    if ( f_juld >= El_beg && f_juld <= El_last )
	{
	if ( f_juld <= El_lconst ) 
	    return ( El_corr ) ;
	else
	    return ( El_corr - El_slope * (f_juld - El_lconst) ) ;
        }
    else
	{
	return ( 0 ) ;
        }
}

/* -------------------------------------------------------------------------- */

