/* misc.c
 *------------------------------------------------------------------------------
 * prday
 * prtime
 * prflags
 * pangle
 * phi
 * get_pB
 * get_doy
 *------------------------------------------------------------------------------
 * Author:  Alice Lecinski   HAO/NCAR    6 Feb 1997
 * Updates: Andrew Stanger   HAO/NCAR   14 Mar 2002
 * 14 Mar 2002: cosmetic changes only.
 *------------------------------------------------------------------------------
 */
#include <stdio.h>

double pi    =  3.1415927535898;
double piov2 =  1.5707963767949;
double piov4 =  0.78539818839745;
double rtd   = 57.29577768930095;
double ba2rad = 0.000383495209178442;		/* 2 pi / 16384 */

extern int idflag, udflag, qdflag, pBflag, posflag, negflag ;

#define COMPRESS_FLAG 1
#define CALIB0_FLAG 2
#define CALIB15_FLAG 4
#define SPEED_FLAG 8
#define CLEAN_FLAG 16
#define TIDY_FLAG 32
#define QUICK_FLAG 64   /* The transformation to rectangular coordinates
			   was done quickly and in-elegantly */
#define PB_FLAG 128
#define Q_FLAG 256
#define U_FLAG 512
#define I_FLAG 1024
#define DIR_FLAG 2048   /* 0 is negative direction (CW) scan, 
			   1 is positive direction (CCW) scan.  */

#define IS_COMPRESS(f) (f & COMPRESS_FLAG)
#define IS_CALIB0(f) (f & CALIB0_FLAG)
#define IS_CALIB15(f) (f & CALIB15_FLAG)
#define IS_SLOW(f) (f & SPEED_FLAG)
#define IS_CLEAN(f) (f & CLEAN_FLAG)
#define IS_TIDY(f) (f & TIDY_FLAG)
#define IS_QUICK(f) (f & QUICK_FLAG)
#define IS_PB(f) (f & PB_FLAG)
#define IS_Q(f) (f & Q_FLAG)
#define IS_U(f) (f & U_FLAG)
#define IS_I(f) (f & I_FLAG)
#define IS_POSDIR(f) (f & DIR_FLAG)
#define IS_NEGDIR(f) (!(f & DIR_FLAG))

/* -------------------------------------------------------------------------- */

char *
prday (i)

register int i;
{
    static char c [10];
    register char *p = c;
    int mon, day, year;

    jdate (i + 2415021, &mon, &day, &year);
    sprintf (p, "%2d/%02d/%2d", mon, day, year - 1900);
    return (p);
}

/* -------------------------------------------------------------------------- */

char *
prtime (i)

register int i;
{
    static char t [12];
    register char *p = t;
    register int hr, min;
    register double sec;

    /* hr = i >> 16; i &= 0xffff; i <<= 16; i |= hr & 0xffff; */

    hr = i / (60 * 60 * 100);
    min = i / (60 * 100) - hr * 60;
    sec = (i * 0.01) - ((hr * 60 + min) * 60.0);
    sprintf (t, "%02d_%02d_%05.2f", hr, min, sec);
    return (p);
}

/* -------------------------------------------------------------------------- */

char *
prflags (f)

register int f;
{
    static char cf [7];
    register char *p = cf;
    pBflag = qdflag = idflag = udflag = posflag = negflag = 0 ;

    /* fprintf(stderr, "Flags are: %o\n", f); */

    *p++ = IS_COMPRESS(f) ? 'C' : ' ';
    *p++ = IS_CALIB0(f) ? '0' : (IS_CALIB15(f) ? '1' : ' ');
    *p++ = IS_SLOW(f) ? 'S' : ' ';
    *p++ = IS_CLEAN(f) ? 'C' : (IS_TIDY(f) ? 'T' : ' ');
    *p++ = IS_PB(f) ? 'P' : 
	   (IS_Q(f) ? 'Q' : (IS_U(f) ? 'U' : (IS_I(f) ? 'I' : ' ' ))) ;
    /* *p++ = IS_PB(f) ? 'P' : (IS_Q(f) ? 'Q' : ' '); */
    if (IS_PB(f)) pBflag = 1 ;
    if (IS_Q(f)) qdflag = 1 ;
    if (IS_U(f)) udflag = 1 ;
    if (IS_I(f)) idflag = 1 ;
    if (IS_POSDIR(f)) posflag=1;
    if (IS_NEGDIR(f)) negflag=1;
    return (cf);
}

/* -------------------------------------------------------------------------- */

double
pangle (i)

register int i;
{
    return (i * pi / (180 * 60));
}

/* -------------------------------------------------------------------------- */

double
phi (i)

register int i;
{
    return (i * pi / 32768);
}

/* -------------------------------------------------------------------------- */

int 
get_pB (f)

register int f;
{
    if ( IS_PB(f) )  return (1) ;
    else             return (0) ;
}

/* -------------------------------------------------------------------------- */

int
get_doy (m, d, yr)

int m, d, yr ; 
{
    static int day_tab [2][13] =
	{ 
	{0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}, 
	{0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}
        };
    int ii, leap ;

    leap = yr%4 == 0 && yr%100 != 0 || yr%400 == 0 ;
    for ( ii = 1 ; ii < m ; ii++ ) d += day_tab [leap][ii] ;
    return (d) ;
}

/* -------------------------------------------------------------------------- */

