/* terpimap.c
 *------------------------------------------------------------------------------
 * Synoptic Map interpolation.
 *------------------------------------------------------------------------------
 * Author:  Alice Lecinski   HAO/NCAR    3 Nov 1997
 * Updates: Andrew Stanger   HAO/NCAR
 * 14 Mar 2002: adapt for Mk4.
 *------------------------------------------------------------------------------
 */

#include <stdio.h>
#include "/home/cordyn/mk4/syn/EWmap4.h"

/* For both Bmap and BCmap (imap and cmap), 
 * longitude goes from 0 to 360 degrees, 
 * with 0 degrees on the left and 360 degrees on the right.
 *
 * Time is reversed, so that the earliest day is on the right, 
 * and the latest day is on the left.
 *
 * In idl, cmap can be displayed with:
 *     a=intary(360, 360)
 *     tvscl, a, order=1
 * In idl, imap can be displayed with:
 *     a=intary(360, 181)
 *     tvscl, a, order=1
 */

extern float INTERPDAY;

extern int  offset ;

/* -------------------------------------------------------------------------- */

terpimap (Long, numlong, smlmap, bigmap, numlat) 

    float Long [] ;		/* Longitude array. */
    int numlong ;  		/* # longitudes in small map. */
    short *smlmap ;		/* Small synoptic map. */
    short *bigmap ;  		/* Big synotpic map. */
    int numlat ;		/* # latitudes. */
{
    register int ii, ilat,  nl ;
    register int   long_hi, long_lo ;
    register int   indx_hi, indx_lo ;
    float deltaL ;
    int   ideltaL ;
    float slope ;

    fprintf (stderr, "\n\tSmoothing between points in the map.\n");

    /*** Longitude loop. ***/

    for (nl = 1 ; nl < numlong ; nl++ )
	{
	long_hi = (int) Long [nl - 1] ;		/* Small map longitude index. */
	long_lo = (int) Long [nl] ;	 

	indx_hi = long_hi + offset ;		/* Big map longitude index. */
	indx_lo = long_lo + offset ;

	deltaL = long_hi - long_lo ;		/* Longitude difference. */
	ideltaL = (int) deltaL ;

	/*** Copy a latitude vector [width=1,   height=numlat] from the big map
	 *** and write a column [width=DAYDEGR, height=numlat] in the small map.
	 ***/

	for ( ilat = 0 ; ilat < numlat ; ilat++ )
	    {
	    for (ii = (-DAYDEGR*0.5) ; ii <= (DAYDEGR*0.5) ; ii++ )
		{
		if ((long_lo + ii >= 0) && (long_lo + ii < LONGS ) )
		    *(smlmap + long_lo + ii + ilat * LONGS) = 
		    *(bigmap +       indx_lo      + ilat * BLONGS) ;
	        }
	    }

	/*** Interpolate if time between samples is less than INTERPDAY. ***/

	if ( ideltaL && ideltaL < INTERPDAY*DAYDEGR )
	    {
	    for ( ilat = 0; ilat < numlat ; ilat++ )
	        {
		slope = (float)(*(bigmap + indx_hi + ilat * BLONGS) 
			      - *(bigmap + indx_lo + ilat * BLONGS))
			      / deltaL ;

		for (ii = 0 ; ii <= ideltaL ; ii++ )
		    {
		    if ((long_lo + ii >= 0) &&
			(long_lo + ii < LONGS ) )
			*(smlmap + long_lo + ii + ilat * LONGS) = 
	 		*(bigmap + indx_lo      + ilat * BLONGS)
			+ (slope * ii) ;
		    }
	        }
	    }
        }

    return (0) ;
}

/* -------------------------------------------------------------------------- */

