/* rdwrtmk4v2.c
 *------------------------------------------------------------------------------
 * readmk4  (filenm, img, doprint)
 * writemk4 (filenm, img, doprint)
 *
 * Reads/Writes a mk4 header and img to/from the file "filenm".
 *
 * "img" is assumed to be a short array.
 *------------------------------------------------------------------------------
 * Author: Alice Lecinski   HAO/NCAR   21 Mar 2000
 * 17 May 2001: [ALS] cosmetic changes only.
 *------------------------------------------------------------------------------
 */

#include <stdio.h>
#include "/home/cordyn/mk4/src/mk4v2.h"
#include "/home/cordyn/mk4/src/mk4headv2.h"
#include "/home/cordyn/mk4/src/crunch.h"
#include "/home/cordyn/mk4/src/telscp4v2.h"
#include "/home/cordyn/mk4/src/drift.h"

/* -------------------------------------------------------------------------- */

int
printit (astring)

char *astring;
{
    fprintf (stderr, "\t%s\t", astring);

    return (0) ;
}

/* -------------------------------------------------------------------------- */

int
readmk4head (filenm, hd, doprint) 

    char   *filenm; 
    struct mk4_header *hd; 
    int    doprint;
{
    int ii, hdsz;
    FILE *fid;

    if (doprint > 0) fprintf (stderr, "Reading header from: %s \n", filenm);

    /*** Open input file. ***/

    if ( ( fid = fopen (filenm, "r") ) == NULL  ) 
	{
	fprintf (stderr, "Error opening %s for reading.\n", filenm);
	exit (-90);
        }

    /*** Read Mk4 header. ***/

    hdsz = sizeof (mk4head);

    if ( ( ii = fread (hd,  1,  hdsz , fid)) != hdsz )
	{
	fprintf (stderr, "Header read error:\n\
		Only read %d bytes from %s\nExpected %d", ii, filenm, hdsz);
	fclose (fid);
	exit (-92);
        }

    fclose (fid);
    return (0) ;
}

/* -------------------------------------------------------------------------- */

int
readmk4 (filenm, hd, img, doprint) 

    char   *filenm; 
    struct mk4_header *hd; 
    short  *img; 
    int    doprint;
{
    int ii, imsz, hdsz;
    FILE *fid;

    if (doprint > 0) fprintf (stderr, "Reading %s\n", filenm);

    /*** Open file. ***/

    if ( ( fid = fopen (filenm, "r") ) == NULL  ) 
	{
	fprintf (stderr, "Error opening %s for reading.\n", filenm);
	exit (-90);
        }

    /*** Read Mk4 header. ***/

    hdsz = sizeof (mk4head);

    if ( ( ii = fread (hd,  1,  hdsz , fid)) != hdsz ) 
	{
	fprintf (stderr, "Header read error:\n\
		 Only read %d bytes from %s\nExpected %d", 
		 ii, filenm, hdsz);
	fclose (fid);
	exit (-92);
        }

    /*** Read Mk4 image data. ***/

    imsz = (hd->Xdim) * (hd->Ydim);

    if ( ( ii = fread (img, sizeof (short), imsz, fid)) != imsz ) 
	{
	fprintf (stderr, "Image read error:\n\
		 Only read %d shorts from %s\nExpected %d", 
		 ii, filenm, imsz);
	fclose (fid);
	exit (-94);
        }
    fclose (fid);

    if (doprint == 1)		/* Print out the sumry info. */
	{		
	printf ("Xdim/Ydim: %d %d \n", hd->Xdim, hd->Ydim);
	printf ("Juld: %s %s \n",      prday (hd->Image.Juld), 
				       prtime (hd->Image.Time));

	switch (hd->DataType) 
	    {  
	    case IS_i:  printf ("This image is i data.\n") ; break;
	    case IS_q:  printf ("This image is q data.\n") ; break;
	    case IS_u:  printf ("This image is u data.\n") ; break;
	    case IS_ba: printf ("This image is ba data.\n") ; break;
	    case IS_sk: printf ("This image is sk data.\n") ; break;
	    case IS_st: printf ("This image is st data.\n") ; break;
	    default:    printf ("This image is UNKNOWN.\n") ;
	    } 
        }
    return (0) ;
}

/* -------------------------------------------------------------------------- */

int
writemk4 (filenm, hd, img, doprint) 

    char   *filenm; 
    struct mk4_header *hd; 
    short  *img; 
    int    doprint;
{
    long  ii, imsz, hdsz;
    FILE *fid;

    if (doprint) fprintf (stderr, "Writing %s\n", filenm);

    /*** Open output file. ***/

    if ( ( fid = fopen (filenm, "w") ) < (FILE*)0 )
	{
	fprintf (stderr, "Error opening %s for writing. Error %d\n",
		 filenm, filenm);
	exit (-90);
        }

    /*** Write Mk4 header. ***/

    hdsz = sizeof (mk4head);

    if ( ( ii = fwrite(hd,  1,  hdsz , fid)) != hdsz )
	{
	fprintf (stderr, "Header write error:\n\
		 Only wrote %d bytes from %s\nExpected %d", 
		 ii, filenm, hdsz);
	fclose (fid);
	exit (-92);
        }

    /*** Write Mk4 image data. ***/

    imsz = (hd->Xdim)*(hd->Ydim);

    if ( ( ii = fwrite (img, sizeof(short), imsz, fid)) != imsz )
	{
	fprintf (stderr, "Image write error:\n\
		 Only wrote %d shorts from %s\nExpected %d", 
		 ii, filenm, imsz);
	fclose (fid);
	exit (-94);
        }

    fclose (fid);
    if (doprint) fprintf (stderr, "\n");
    return (0) ;
}

/* -------------------------------------------------------------------------- */

int
readtscp (filenm, hd, doprint)

    char   *filenm; 
    struct telhd *hd; 
    int    doprint;
{
    long  ii, hdsz;
    FILE *fid;

    if (doprint) fprintf (stderr, "Reading %s\n", filenm);

    /*** Open input file. ***/

    if ( ( fid = fopen (filenm, "r") ) < (FILE*)0 )
	{
	fprintf(stderr, "Error opening %s for reading.\n", filenm);
	exit (-90);
        }

    /*** Read telescope file. ***/

    hdsz = sizeof (telscp);

    if ( ( ii = fread (hd,  1,  hdsz , fid)) != hdsz )
	{
	fprintf (stderr, "Telescope read error:\n\
		 Only read %d bytes from %s\nExpected %d", 
		 ii, filenm, hdsz);
	fclose (fid);
	exit (-92);
        }

    fclose (fid);
    if (doprint) fprintf (stderr, "\n");
    return (0) ;
}

/* -------------------------------------------------------------------------- */

int
writetscp (filenm, hd, doprint)

    char   *filenm; 
    struct telhd *hd; 
    int    doprint;
{
    long  ii, hdsz;
    FILE *fid;

    if (doprint) fprintf (stderr, "Writing %s\n", filenm);

    /*** Open output file. ***/

    if ( ( fid = fopen (filenm, "w") ) < (FILE*)0 )
	{
	fprintf (stderr, "Error opening %s for writing.\n",
		 filenm);
	exit (-90);
        }

    /*** Write telescope file. ***/

    hdsz = sizeof (telscp);

    if ( ( ii = fwrite (hd,  1,  hdsz , fid)) != hdsz )
	{
	fprintf (stderr, "Telescope write error:\n\
		 Only wrote %d bytes from %s\nExpected %d", 
		 ii, filenm, hdsz);
	fclose (fid);
	exit (-92);
        }

    fclose (fid);
    if (doprint) fprintf (stderr, "\n");
    return (0) ;
}

/* -------------------------------------------------------------------------- */

int
readdrift (filenm, hd, doprint)

    char   *filenm; 
    struct drifthd *hd; 
    int    doprint;
{
    long  ii, hdsz;
    FILE *fid;

    if (doprint) fprintf (stderr, "Reading %s\n", filenm);

    /*** Open input file. ***/

    if ( ( fid = fopen (filenm, "r") ) < (FILE*)0 )
	{
	fprintf (stderr, "Error opening %s for reading.\n",
		 filenm);
	exit (-90);
        }

    /*** Read drfit file. ***/

    hdsz = sizeof(drifthead);

    if ( ( ii = fread (hd,  1,  hdsz , fid)) != hdsz )
	{
	fprintf (stderr, "Drift file read error:\n\
		 Only read %d bytes from %s\nExpected %d", 
		 ii, filenm, hdsz);
	fclose (fid);
	exit (-92);
        }

    fclose (fid);
    if (doprint) fprintf (stderr, "\n");
    return (0) ;
}

/* -------------------------------------------------------------------------- */

int
writedrift (filenm, hd, doprint)

    char   *filenm; 
    struct drifthd *hd; 
    int    doprint;
{
    long  ii, hdsz;
    FILE *fid;

    if (doprint) fprintf (stderr, "Writing %s\n", filenm);

    /*** Open output file. ***/

    if ( ( fid = fopen (filenm, "w") ) < (FILE*)0 )
	{
	fprintf (stderr, "Error opening %s for writing.\n", filenm);
	exit (-90);
        }

    /*** Write drift data. ***/

    hdsz = sizeof (drifthead);

    if( ( ii = fwrite (hd,  1,  hdsz , fid)) != hdsz )
	{
	fprintf (stderr, "Drift file write error:\n\
		 Only wrote %d bytes from %s\nExpected %d", 
		 ii, filenm, hdsz);
	fclose (fid);
	exit (-92);
        }

    fclose (fid);
    if (doprint) fprintf (stderr, "\n");
    return (0) ;
}
