/* sinfo4.c
 *------------------------------------------------------------------------------
 *  This program takes the information you give it,
 *  either  date and time   or   long and carrington rotation,
 *  and gives you TONS of information about it.
 *------------------------------------------------------------------------------
 * Author:  Alice Lecinski   HAO/NCAR
 * Updates: Andrew Stanger   HAO/NCAR
 * 2 Dec 2002: Adapt for Mk4.
 *------------------------------------------------------------------------------
 */

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <sys/types.h>
#include "/home/cordyn/mk4/syn/EWmap4.h"
#include "/home/cordyn/mk4/syn/ephemeris.h"

int idflag, udflag, qdflag, pBflag, posflag, negflag ;
int cal0flag,quickflag,cal15flag,year,Neflag;

char filenm [100] ;

int     east, west, CMmap ;
int     Tmon, Tyear, Tday, Tdoy ;
float   Tlong ;
int     Trot ;
float   Thour, Tmin, FTdoy ;

int     iCR, leap ;
int           Ebdoy, Eedoy , Ebyr, Eeyr ;
int           Wbdoy, Wedoy , Wbyr, Weyr ;
int           Cbdoy, Cedoy , Cbyr, Ceyr ;
int     FEbdoy, FEedoy , FEbyr, FEeyr ;
int     FWbdoy, FWedoy , FWbyr, FWeyr ;

long    iFbegEj, iFendEj, iFbegWj, iFendWj ;
long    ibegEj,  iendEj,  ibegWj,  iendWj, ibegCj, iendCj ;
double  begEj, endEj, begWj, endWj, begCj, endCj ;
double  slopeE, slopeW, slopeC ;

main (an, av)

int an ;
char *av[] ;
{
    register int ii, jj, kk ;
    register char *w;
    register float *fp;
    float elong, wlong , clong ;
    int isdate ;
    int islong ;
    int argcnt ;
    int eday, wday  ;
    double f_juld ;
    u_short Tjuld;
    unsigned Ttime;
    FILE *fid;

    void get_slopes (), ck_get_day (), ck_get_long (),
         do_mapout (), do_fileout () ;

    isdate = CMmap = west = east = 0 ;

    if ( an <= 1 ) { pruse () ; exit (3) ; }
    argcnt = an -2 ;

    while (--an)
	{
	if (*(w = *++av) == '-')	/* Check for flag arguments */
	    switch (w [1])
	    {
	    case 'd':   isdate++; 
			if (argcnt == 4)
			    {
			    an -= 4; 
			    Tdoy  = atoi (*++av) ;
			    Tyear = atoi (*++av) ;
			    if (Tyear < 1900) Tyear += 1900;
			    mon_day (Tdoy, Tyear, &Tmon, &Tday);
			    }
			if (argcnt == 5)
			    {
			    an -= 5; 
			    Tmon  = atoi (*++av);
			    Tday  = atoi (*++av);
			    Tyear = atoi (*++av);
			    if (Tyear < 1900) Tyear += 1900;
			    Tdoy = Idoy (Tmon, Tday, Tyear);
			    }
			Thour  = atoi (*++av);
			Tmin   = atoi (*++av);
			FTdoy = (float) Tdoy + Thour/24.0  + Tmin / (24.0*60.0);
			break ;
	    case 'e':   east++;		/* East limb longitude */
			an -= 2; 
			Tlong = atof (*++av);
			Trot  = atoi (*++av);
			break ;
	    case 'w':   west++;		/* West limb longitude */
			an -= 2; 
			Tlong = atof (*++av);
			Trot  = atoi (*++av);
			break ;
	    case 'c':   CMmap++;	/* central meridian longitude */
			an -= 2; 
			Tlong = atof (*++av);
			Trot  = atoi (*++av);
			break ;
	    default:    fprintf (stderr," unknown flag %s\n", *av);
		        pruse (); exit (1);
	    }

	else
	    {
	    pruse (); exit (2);
	    }
        }

    if (isdate) 	       findrot_date (FTdoy, Tyear ) ;
    if ( east + west + CMmap ) findrot_rot (Trot) ;
      
    rotdata (iCR) ;
    get_slopes () ;	/* Get the slopes for the conversion to longitude. */

    if (isdate)
	{
	Tjuld = (u_short)( jday ( Tmon, Tday, Tyear ) - 2415021 ) ;
	Ttime = (unsigned) (Thour*60*60*100 + Tmin*60*100 ) ;
	ck_get_day  (Tjuld, Ttime, &eday, &wday, &f_juld) ;
	ck_get_long (Tjuld, Ttime, &elong, &wlong, &clong, &f_juld) ;
        }
    if (east)
	{
	elong = Tlong ;
	clong = elong +  90 ;
	wlong = elong + 180 ;
        }
    if (west)
	{
	wlong = Tlong ;
	clong = wlong - 90 ;
	elong = wlong - 180 ;
        }
    if (CMmap)
	{
	clong = Tlong ;
	elong = clong - 90 ;
	wlong = clong + 90 ;
        }
    if (east + west + CMmap)
	{
	ck_get_dates (elong, wlong, clong) ;
	Tjuld = (u_short) ( jday ( Tmon, Tday, Tyear ) - 2415021 ) ;
	Ttime = (unsigned) (Thour*60*60*100 + Tmin*60*100 ) ;
	ck_get_day  (Tjuld, Ttime, &eday, &wday, &f_juld) ;
        }

    nmfile () ;

    fprintf (stdout,"\
Mon %2d Day %2d Year %d \n\
DOY %d \n\
hour %.0f  min %.2f     (  DOY  --> %.2f )  \n\
\n\
elong %3.1f      wlong %3.1f     clong %3.1f     Crot %d \n\
\n\
eday %3d       wday %3d     \n\
\n\
file %s \n\
\n", 
Tmon, Tday, Tyear, 
Tdoy,
Thour,Tmin,(Tdoy+(Thour/24.0)+(Tmin/(24.0*60.0))),
elong,wlong,clong,Trot,
eday,wday,
filenm ) ;

    exit (0) ;
}

/* -------------------------------------------------------------------------- */

void
get_slopes ()

{
    slopeE = 360.0  / ( endEj - begEj )  ;
    slopeW = 360.0  / ( endWj - begWj )  ;
    slopeC = 360.0  / ( endCj - begCj )  ;
}

/* -------------------------------------------------------------------------- */

pruse ()
{
static char usage [] = "\
\n\
Standard usage is: \n\
    sinfo [-d  mon day year hour min] \n\
    sinfo [-d  doy year hour min] \n\
    sinfo [-e  elong rotation] \n\
    sinfo [-w  wlong rotation] \n\
    sinfo [-c  central_meridian_longitude rotation] \n\n" ;
    fputs (usage,stderr);

    return (0) ;
}

/* -------------------------------------------------------------------------- */

int
findrot_date (FTdoy, Tyear) 

    float FTdoy ;
    int   Tyear ; 
{
    int ii ;

    if ( Tyear < (int) CRtable [0][2] || Tyear > (int) CRtable [ep_sz-1][2] )
	{
	fprintf (stderr,"\
	Rats !  There is no ephemeris entry for your year %d.  Hence this\n\
	program can't procede.  Someone will have to update the file \n\
	/home/cordyn/mk4/syn/ephemeris.h\n\n"
	,Tyear  ) ;
	exit (12) ;
        }
    ii = 0 ;
    while (  Tyear > (int) CRtable [ii][2] ) ii++ ;
    while (  FTdoy >       CRtable [ii][1] ) ii++ ;
    ii-- ;
    Trot = CRtable [ii][0] ;
    iCR = ii ;

    return (0) ;
}

/* -------------------------------------------------------------------------- */

findrot_rot (Trot) 
        int  Trot ;
{
    int ii ;

    if ( Trot < (int)CRtable[0][0] || Trot > (int)CRtable[ep_sz-1][0] )
	{
	fprintf(stderr,"\
	Rats !  There is no ephemeris entry for your rotation %d.  Hence this\n\
	program can't procede.  Someone will have to update the file \n\
	/home/cordyn/mk4/syn/ephemeris.h\n\n"
	,Trot  ) ;
	exit(12) ;
        }
    ii = 0  ;
    while (  Trot > (int) CRtable [ii][0] ) ii++ ;
    iCR = ii ;

    return (0) ;
}

extern int   mon_day() ;
extern int   jday()  ;
extern int   jdate() ;
extern int   iday()  ;


double juld_last, juld_this, juld_next , juld_future, frac_day ;
int mon, day, yr, doy ;

int rotdata (ii) 
	     int   ii ; 
{
    int isleap() ;
      
    /*  Determine the beginning and ending days. */

    doy = (int) ( CRtable[ii-1][1] ) ; yr = (int) CRtable[ii-1][2] ;
    frac_day =  CRtable[ii-1][1] - (double) doy ;
    mon_day ( doy, yr, &mon, &day );
    juld_last = (double)jday ( mon, day, yr ) +frac_day ;  

    doy = (int) ( CRtable[ii][1] ) ; yr = CRtable[ii][2] ;
    frac_day =  CRtable[ii][1] - (double) doy ;
    mon_day ( doy, yr, &mon, &day );
    juld_this = (double)jday ( mon, day, yr ) +frac_day ;  

    doy = (int) ( CRtable[ii+1][1] ) ; yr = CRtable[ii+1][2] ;
    frac_day =  CRtable[ii+1][1] - (double) doy ;
    mon_day ( doy, yr, &mon, &day );
    juld_next = (double)jday ( mon, day, yr ) + frac_day ;  

    doy = (int) ( CRtable[ii+2][1] ) ; yr = CRtable[ii+2][2] ;
    frac_day =  CRtable[ii+2][1] - (double) doy ;
    mon_day ( doy, yr, &mon, &day );
    juld_future = (double)jday ( mon, day, yr ) +frac_day ;  


    begEj = juld_this - ( juld_this - juld_last ) / 4.0 ; ibegEj = (long)begEj ;
    endEj = juld_next - ( juld_next - juld_this ) / 4.0 ; iendEj = (long)endEj ;

    begWj = juld_this + ( juld_next - juld_this ) / 4.0 ; ibegWj = (long)begWj ;
    endWj = juld_next + ( juld_future - juld_next ) / 4.0 ; iendWj =(long)endWj;

    begCj = juld_this ;                                   ibegCj = (long)begCj ;
    endCj = juld_next ;                                   iendCj = (long)endCj ;

    iFbegEj = (long) (juld_this + SHIFTE ) ;
    iFendEj = iFbegEj + 33 ;
    iFbegWj = (long) (juld_this + SHIFTW ) ;
    iFendWj = iFbegWj + 33 ;

    {   /* east */
	jdate ( ibegEj, &mon, &day, &yr ) ;  
	Ebyr = yr ; Ebdoy = iday ( mon, day, yr ) ;
	jdate ( iendEj, &mon, &day, &yr ) ;  
	Eeyr = yr ; Eedoy = iday ( mon, day, yr ) ;

	jdate ( iFbegEj, &mon, &day, &yr ) ;  
	FEbyr = yr ; FEbdoy = iday ( mon, day, yr ) ;
	jdate ( iFendEj, &mon, &day, &yr ) ;  
	FEeyr = yr ; FEedoy = iday ( mon, day, yr ) ;
    }

    {   /* west */
	jdate ( ibegWj, &mon, &day, &yr ) ;  
	Wbyr = yr ; Wbdoy = iday ( mon, day, yr ) ;
	jdate ( iendWj, &mon, &day, &yr ) ;  
	Weyr = yr ; Wedoy = iday ( mon, day, yr ) ;

	jdate ( iFbegWj, &mon, &day, &yr ) ;  
	FWbyr = yr ; FWbdoy = iday ( mon, day, yr ) ;
	jdate ( iFendWj, &mon, &day, &yr ) ;  
	FWeyr = yr ; FWedoy = iday ( mon, day, yr ) ;
    }

    { /* Central Meridian */
	jdate ( ibegCj, &mon, &day, &yr ) ;  
	Cbyr = yr ; Cbdoy = iday ( mon, day, yr ) ;
	jdate ( iendCj, &mon, &day, &yr ) ;  
	Ceyr = yr ; Cedoy = iday ( mon, day, yr ) ;
    }
}


nmfile() 
{
    int ii ;

    /*  Find the filename.  Each SYN___ file contains 10days, 
        hence the /10 and *10 stuff below. */
    ii=(Tdoy/10)*10 ; 
    if (ii==0 ) ii+=1;
    Sname ( ii, Tyear, filenm ) ;
}

ck_get_dates (elong,wlong,clong) 
	    float elong, wlong, clong ; 
{
    double jdt ;

    if ( east ) {
	jdt  = begEj + (360.0-(double)elong)/slopeE  ;
    }

    if ( west ) {
	jdt  = begWj + (360.0-(double)wlong)/slopeW  ;
    }

    if ( CMmap ) {
	jdt  = begCj + (360.0-(double)clong)/slopeC  ;
    }
    jdate ( (long)jdt, &Tmon, &Tday, &Tyear ) ;  
    Tdoy = Idoy (Tmon, Tday, Tyear) ;

    Thour =  (float)( (int)( 24*(jdt - (long)jdt) ) ) ;
    Tmin =  60* ( 24*(jdt-(long)jdt)   -  Thour ) ;

}
